<?php

/*
 * 饯ɲ
 * $Id: addchar.php,v 1.16 2003/01/25 05:21:26 yuryu Exp $
 *
 */

require_once("./common.php");
require_once("./settings.php");
require_once("./plist.php");
require_once("./clist.php");
require_once("./readxmls.php");

	$_POST = merge_cookie($_POST);

	switch($_REQUEST['method']){
		case "add": add_character(); break;
		case "remove": remove_character(); break;
		case "modify": modify_character(); break;
		default: 	show_entryform($_REQUEST); break;
	}
	

function remove_character()
{
	$charlist = new CharacterList(CHARDATA_FNAME);
	$playerlist = new PlayerList(PLAYERDATA_FNAME);

	$chardata = convert_request_to_chardata($_POST);

	if(! $playerlist -> authorize($chardata['player'], $_POST['password'])){
		$_REQUEST['password'] = '';
		bake_cookie();
		show_error("ǧڥ顼", "ץ쥤䡼ȥѥɤפޤ", true);
	}
	
	$charlist -> remove($chardata['name']);
	
	show_header("饯Ͽ/ѹ");
	print("<p>ʲ̤ꡢ饯Ͽޤѹդޤ</p><p><a href='./'></a></p>\n");

	printf("<p> - %s</p>\n", $chardata['name']);
	
	show_footer();
	
}

function add_character()
{

	$charlist = new CharacterList(CHARDATA_FNAME);
	$playerlist = new PlayerList(PLAYERDATA_FNAME);

	$chardata = convert_request_to_chardata($_POST);

	if(! $playerlist -> authorize($chardata['player'], $_POST['password'])){
		$_REQUEST['password'] = '';
		bake_cookie();
		show_error("ǧڥ顼", "ץ쥤䡼ȥѥɤפޤ", true);
	}
	
	$stored_data = $charlist -> get($chardata['name']);
	if($stored_data and $stored_data['player'] != $chardata['player']){
		show_error("ʣϿ", sprintf("Υ饯ϤǤ̤Υץ쥤(%s)ˤäϿƤޤ", $stored_data['player']), true);
	}

	if($stored_data){
		$chardata['main'] = $stored_data['main'];
	}
	$charlist -> set($chardata, true);
	
	global $guild_xmls;
	parse_xml($guild_xmls[$chardata['guild']]);
	
	$chardata = $charlist -> get($chardata['name']);
	
	$chardata['password'] = $_REQUEST['password'];
	
	bake_cookie($chardata);
	
	show_header("饯Ͽ/ѹ");
	print("<p>ʲ̤ꡢ饯Ͽޤѹդޤ</p><p><a href='./'></a></p>\n<dl>");
	
	$chardata = a_htmlspecialchars($chardata);
	
	printf("<dt>ץ쥤̾(ID)</dt><dd>%s</dd>\n", $chardata['player']);
	printf("<dt>饯̾</dt><dd>%s</dd>\n", $chardata['name']);
	printf("<dt>٥</dt><dd>%d</dd>\n", $chardata['level']);
	printf("<dt>²</dt><dd>%s</dd>\n", $chardata['race']);
	printf("<dt></dt><dd>%s</dd>\n", $chardata['class']);
	if(! GUILD_SPEC){
		printf("<dt></dt><dd>%s</dd>\n", $chardata['guild']);
	}
	printf("<dt></dt><dd>%s</dd>\n", $chardata['comment']);
	
	print("</dl>\n");
	
	show_footer();

}

function modify_character()
{
	$charlist = new CharacterList(CHARDATA_FNAME);
	
	$chardata = $charlist -> get($_REQUEST['name']);
	$chardata['password'] = $_REQUEST['password'];
	if($chardata == false){
		show_error("饯Խ", "ꤵ줿̾Υ饯ĤޤǤ", true);
	}
	show_header("饯Խ");
	
	show_entryform($chardata);
	
	show_footer();
	
}


function check_serenity($request)
{
	$section_name = '饯ɲ';
	
	if($request['name'] == ''){
		show_error($section_name, "饯̾Ǥ", true);
	}

}


function show_error($title, $message, $show_form)
{
	show_header('顼');
	bake_cookie();
	printf("<p class='error' id='error'>%s - %s</p>\n", $title, $message);
	if($show_form){
		show_entryform($_REQUEST);
	}
	show_footer();
	exit;
}

function show_entryform($request)
{
	show_header('饯ɲ');
	
	$request = a_htmlspecialchars($request);

	print("<p>Ĥξ Herald  XML ƤޤΤǡɬפϤޤ");
	if(! GUILD_SPEC){
		print("ɤФʤȾ󤬹ޤ");
	}
	print("</p>\n");
	
	print("<form id='characterform' method='post' action='addchar'><dl>");
  
 	printf("<dt>ץ쥤̾(ID)</dt><dd><input name='player' type='text' value='%s' maxlength='%d' size='%d' /></dd>\n",
 				$request['player'], MAX_PLAYERNAME_LENGTH, MAX_PLAYERNAME_LENGTH);
	printf("<dt>ѥ</dt><dd><input name='password' type='password' maxlength='%d' size='%d' value='%s' /></dd>\n",
				MAX_PASSWORD_LENGTH, MAX_PASSWORD_LENGTH, $request['password']);
	printf("<dt>̾</dt><dd><input name='name' type='text' value='%s' maxlength='%d' size='%d' /></dd>\n",
				$request['name'], MAX_CHARNAME_LENGTH, MAX_CHARNAME_LENGTH);
	
	if(! GUILD_SPEC){
		print("<dt></dt><dd><select name='guild'>\n");
		global $guild_list;
		foreach($guild_list as $guild => $guilddata){
			if($guild == $request['guild']){
				printf("<option selected='selected' value='%s'>%s</option>\n", $guild, $guilddata['Name']);
			}else{
				printf("<option value='%s'>%s</option>\n", $guild, $guilddata['Name']);
			}
		}
		print("</select></dd>\n");
	}
	
	printf("<dt>(%dʸޤ)</dt><dd><input type='text' name='comment' size='80' maxlength='%d' value='%s' /></dd>\n",
				MAX_COMMENT_LENGTH, MAX_COMMENT_LENGTH, $request['comment']);

	
	printf("<dt><input type='hidden' name='main' value='%s' />", $request['main']);

	print("<input type='radio' name='method' value='add' checked='checked' />饯ɲ/ѹ <input type='radio' name='method' value='remove' />饯</dt>");
	
	print("<dt><button type='submit'></button> <button type='reset'>ꥻå</button></dt></dl></form>");

	print("<p><a href='./'>ꥹȤ</a></p>");

	show_footer();
	
}


function convert_request_to_chardata($request)
{
	check_serenity($request);

	$result['name'] = $request['name'];
	$result['player'] = $request['player'];
	if(GUILD_SPEC){
		$result['guild'] = GUILD_SPEC;
	}else{
		$result['guild'] = $request['guild'];
	}

	$result['comment'] = $request['comment'];
	
	$result['main'] = $request['main'];
	
	$result['date'] = date(DATE_FORMAT);
	
	return $result;
}

function bake_cookie($request = array())
{
	setcookie('player', $request['player'], time() + COOKIE_EXPIRES_IN);
	setcookie('password', $request['password'], time() + COOKIE_EXPIRES_IN);
	setcookie('guild', $request['guild'], time() + COOKIE_EXPIRES_IN);
}

?>
